import 'package:flutter/material.dart';
import 'package:og1_ui/src/models/_models.dart';

class Og1DesktopLayout extends StatelessWidget {
  final PreferredSizeWidget? appBar;
  final Widget body;
  final List<TabModel> tabs;
  final int currentIndex;
  final Function(int id) onTap;
  final bool isDesktop;
  final double sideMenuWidth;

  const Og1DesktopLayout({
    Key? key,
    this.appBar,
    required this.body,
    required this.tabs,
    required this.currentIndex,
    required this.onTap,
    this.isDesktop = true,
    this.sideMenuWidth = 150.0,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: appBar,
      body: Row(
        children: [
          SingleChildScrollView(
            controller: ScrollController(),
            child: ConstrainedBox(
              constraints:
                  BoxConstraints(minHeight: MediaQuery.of(context).size.height),
              child: IntrinsicHeight(
                child: NavigationRail(
                    extended: isDesktop,
                    minExtendedWidth: 150,
                    labelType: isDesktop
                        ? NavigationRailLabelType.none
                        : NavigationRailLabelType.all,
                    selectedIndex: currentIndex,
                    onDestinationSelected: onTap,
                    destinations: tabs
                        .map((tab) => NavigationRailDestination(
                              label: Text(tab.label),
                              icon: tab.icon,
                            ))
                        .toList()),
              ),
            ),
          ),
          Expanded(child: body),
        ],
      ),
    );
  }
}
