import 'package:flutter/material.dart';
import 'package:og1_system/og1_system.dart';
import 'package:og1_ui/src/models/_models.dart';

import '_layout_widgets.dart';

class Og1Layout extends StatelessWidget {
  final PreferredSizeWidget? appBar;
  final Widget body;
  final List<TabModel> tabs;
  final int currentIndex;
  final Function(int id) onTap;
  final double sideMenuWidth;
  final bool desktopLayout;

  const Og1Layout({
    Key? key,
    this.appBar,
    required this.body,
    required this.tabs,
    required this.currentIndex,
    required this.onTap,
    this.sideMenuWidth = 250.0,
    this.desktopLayout = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ResponsiveBuilder(builder: (context, sizingInformation) {
      if (sizingInformation.isMobile) {
        return Og1MobileLayout(
          appBar: appBar,
          body: body,
          tabs: tabs,
          currentIndex: currentIndex,
          onTap: onTap,
        );
      }
      return Og1DesktopLayout(
        appBar: appBar,
        body: body,
        tabs: tabs,
        currentIndex: currentIndex,
        onTap: onTap,
        isDesktop: desktopLayout && sizingInformation.isDesktop,
        sideMenuWidth: sideMenuWidth,
      );
    });
  }
}
