import 'package:flutter/material.dart';
import 'package:og1_ui/src/models/_models.dart';
import 'package:og1_ui/src/widgets/_widgets.dart';

class Og1LanguagePicker extends StatelessWidget {
  final List<LanguageModel> supportedLanguages;
  final LanguageModel language;
  final Function(LanguageModel? language) onLanguageChange;
  final bool displayText;
  final double width;
  final double height;

  const Og1LanguagePicker({
    Key? key,
    required this.supportedLanguages,
    required this.language,
    required this.onLanguageChange,
    this.displayText = false,
    this.width = 70,
    this.height = 70,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: width,
      height: height,
      child: PopupMenuButton<LanguageModel>(
        icon: Og1Language(
          language: language,
          displayText: false,
        ),
        onSelected: onLanguageChange,
        itemBuilder: (BuildContext context) => supportedLanguages
            .map<PopupMenuEntry<LanguageModel>>(
              (lang) => PopupMenuItem<LanguageModel>(
                value: lang,
                child: Og1Language(
                  key: UniqueKey(),
                  language: lang,
                  displayText: displayText,
                ),
              ),
            )
            .toList(),
      ),
    );
  }
}
